function info = get_trackinfo(track, car_pos)

seg_idx = -1;
for i = 1:track.nr_seg 
    curr_bd = track.seg{i}.bd;
    if inpolygon(car_pos(1), car_pos(2), curr_bd(:, 1), curr_bd(:, 2))
        seg_idx = i;
        break;
    end
end

info.seg_idx = seg_idx;

% If car_pos is inside the track, 
% 1) compute dist from center / 2) compute geodesic dist
if seg_idx > 0
    seg = track.seg{seg_idx};
    info.seg = seg;
    info.type = seg.type;
    info.startpos = seg.startpos;
    prev_dist = 0;
    for i = 1:seg_idx - 1
        prev_dist = prev_dist + track.seg{i}.len;
    end
    switch info.type
        case 'straight'
            % deviation
            a = seg.startpos(1:2);
            b = seg.endpos(1:2);
            x = car_pos(1:2);
            info.dev = get_distfrpnt2line(x, a, b);
            % distance
            a = seg.p(1, :);
            b = seg.p(4, :);
            info.dist = prev_dist + get_distfrpnt2line(x, a, b);
        case 'right_turn'
            org = seg.centerpos(1:2);
            pntA = seg.startpos(1:2);
            pntB = car_pos(1:2);
            deg_diff = get_degbtwlines(org, pntA, pntB);
            info.deg = mod(seg.startpos(3) + 90 + deg_diff, 360); % wrt seg.centerpos
            info.r   = norm(org - car_pos(1:2));
            info.dev = seg.d - info.r; 
            % distance
            info.dist = prev_dist + 2*pi*seg.d*abs(deg_diff)/360;
        case 'left_turn'
            org = seg.centerpos(1:2);
            pntA = seg.startpos(1:2);
            pntB = car_pos(1:2);
            deg_diff = get_degbtwlines(org, pntA, pntB);
            info.deg = mod(seg.startpos(3) - 90 + deg_diff, 360); % wrt seg.centerpos
            info.r   = norm(org - car_pos(1:2));
            info.dev = info.r - seg.d; 
            % distance
            info.dist = prev_dist + 2*pi*seg.d*abs(deg_diff)/360;     
    end
    % Lane idx
    nr_lane = track.nr_lane;
    width = seg.width;
    dev = info.dev;
    unit_len = width / nr_lane;
    lane_idx = ceil( (dev+width/2) / unit_len);
    info.lane_idx = lane_idx;
else
    info.dev = nan;
    info.dist = nan;
    info.lane_idx = -1;
end

